commit-gnuradio
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Commit-gnuradio] [gnuradio] 01/01: fft: fixed Nuttall window naming fro


From: git
Subject: [Commit-gnuradio] [gnuradio] 01/01: fft: fixed Nuttall window naming from nuttal to nuttall.
Date: Mon, 24 Nov 2014 23:23:14 +0000 (UTC)

This is an automated email from the git hooks/post-receive script.

trondeau pushed a commit to branch master
in repository gnuradio.

commit b2e6c0f247784ba4119cd6aa32998e7fcfa43f77
Author: Tom Rondeau <address@hidden>
Date:   Mon Nov 24 18:20:31 2014 -0500

    fft: fixed Nuttall window naming from nuttal to nuttall.
    
    The old calls to nuttal are still there to preserve the API but they just 
point to the nuttall versions and their docs have been updated to indicate 
these calls are deprecated. Will be removed in 3.8.
---
 gr-fft/include/gnuradio/fft/window.h | 23 +++++++++++++++++++----
 gr-fft/lib/window.cc                 | 20 +++++++++++++++++++-
 2 files changed, 38 insertions(+), 5 deletions(-)

diff --git a/gr-fft/lib/window.cc b/gr-fft/lib/window.cc
index 965b11b..126b289 100644
--- a/gr-fft/lib/window.cc
+++ b/gr-fft/lib/window.cc
@@ -209,18 +209,36 @@ namespace gr {
     std::vector<float>
     window::nuttal(int ntaps)
     {
+      return nuttall(ntaps);
+    }
+
+    std::vector<float>
+    window::nuttall(int ntaps)
+    {
       return coswindow(ntaps, 0.3635819, 0.4891775, 0.1365995, 0.0106411);
     }
 
     std::vector<float>
     window::blackman_nuttal(int ntaps)
     {
-      return nuttal(ntaps);
+      return nuttall(ntaps);
+    }
+
+    std::vector<float>
+    window::blackman_nuttall(int ntaps)
+    {
+      return nuttall(ntaps);
     }
 
     std::vector<float>
     window::nuttal_cfd(int ntaps)
     {
+      return nuttall_cfd(ntaps);
+    }
+
+    std::vector<float>
+    window::nuttall_cfd(int ntaps)
+    {
       return coswindow(ntaps, 0.355768, 0.487396, 0.144232, 0.012604);
     }
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/gr-fft/include/gnuradio/fft/window.h 
b/gr-fft/include/gnuradio/fft/window.h
index c1de181..4b13ddd 100644
--- a/gr-fft/include/gnuradio/fft/window.h
+++ b/gr-fft/include/gnuradio/fft/window.h
@@ -179,32 +179,47 @@ namespace gr {
       static std::vector<float> blackmanharris(int ntaps, int atten=92);
 
       /*!
        * \brief Build a Nuttal (or Blackman-Nuttal) window.
        *
        * See: 
http://en.wikipedia.org/wiki/Window_function#Blackman.E2.80.93Nuttall_window
        *
        * \param ntaps Number of coefficients in the window.
        */
+      static std::vector<float> nuttall(int ntaps);
+
+      /*!
+       * Deprecated: use nuttall window instead.
+       */
       static std::vector<float> nuttal(int ntaps);
 
       /*!
        * \brief Alias to the Nuttal window.
        *
        * \param ntaps Number of coefficients in the window.
        */
+      static std::vector<float> blackman_nuttall(int ntaps);
+
+      /*!
+       * Deprecated: use blackman_nuttall window instead.
+       */
       static std::vector<float> blackman_nuttal(int ntaps);
 
       /*!
        * \brief Build a Nuttal continuous first derivative window.
        *
        * See: 
http://en.wikipedia.org/wiki/Window_function#Nuttall_window.2C_continuous_first_derivative
        *
        * \param ntaps Number of coefficients in the window.
        */
+      static std::vector<float> nuttall_cfd(int ntaps);
+
+      /*!
+       * Deprecated: use nuttall_cfd window instead.
+       */
       static std::vector<float> nuttal_cfd(int ntaps);
 
       /*!
-       * \brief Build a Nuttal continuous first derivative window.
+       * \brief Build a flat top window.
        *
        * See: http://en.wikipedia.org/wiki/Window_function#Flat_top_window
        *
@@ -179,32 +179,47 @@ namespace gr {
 
       /*!
-       * \brief Build a Nuttal (or Blackman-Nuttal) window.
+       * \brief Build a Nuttall (or Blackman-Nuttall) window.
        *
        * See: 
@@ -179,32 +179,47 @@ namespace gr {
 
       /*!
-       * \brief Alias to the Nuttal window.
+       * \brief Alias to the Nuttall window.
        *
        * \param ntaps Number of coefficients in the window.
@@ -179,32 +179,47 @@ namespace gr {
 
       /*!
-       * \brief Build a Nuttal continuous first derivative window.
+       * \brief Build a Nuttall continuous first derivative window.
        *
        * See: 